#!/usr/bin/env python
# coding: utf-8

# # How To: Find missing topologies that are not covered by the database

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append("."); import smodels_paths


# In[2]:


# Import those parts of smodels that are needed for this exercise
from smodels.tools.physicsUnits import TeV, GeV, fb
from smodels.installation import installDirectory
from smodels.share.models.mssm import BSMList
from smodels.share.models.SMparticles import SMList
from smodels.theory.model import Model
from smodels.theory import decomposer
from smodels.theory.theoryPrediction import theoryPredictionsFor
from smodels.experiment.databaseObj import Database
from smodels.tools import coverage


# In[3]:


# Define the SLHA input file name
filename="inputFiles/slha/gluino_squarks.slha" 
model = Model(BSMparticles = BSMList, SMparticles = SMList)
model.updateParticles(inputFile=filename)


# In[4]:


# Load the database, do the decomposition and compute theory predictions:
# (Look at the theory predictions HowTo to learn how to compute theory predictions)
database = Database("official")
expResults = database.getExpResults()
topList = decomposer.decompose(model, sigmacut = 0.03 * fb, doCompress=True, doInvisible=True,minmassgap = 5* GeV)
#(Computing theory predictions will tag the elements which have been tested)
allThPredictions = [theoryPredictionsFor(exp, topList) for exp in expResults]


# In[8]:


#Find out missing topologies:
uncovered = coverage.Uncovered(topList)
#First sort coverage groups by label
groups = sorted(uncovered.groups[:], key = lambda g: g.label)


# In[10]:


#Print uncovered cross-sections:
for group in groups:
    print("\nTotal cross-section for %s (fb): %10.3E" %(group.description,group.getTotalXSec()))


# In[16]:


# Get list of topologies which are not tested by any result:
missingTopos = uncovered.getGroup('missing (all)')
# print information about the first few missing topologies and
# the elements contributing to the topology: 
for genEl in missingTopos.generalElements[:5]:
    print ('\nmissing topology:',str(genEl._outputDescription))
    print ('Contributing elements:')
    for el in genEl._contributingElements:
        print('\t',el)


# In[21]:


# Get list of topologies which are not tested by any result:
outsideGrid = uncovered.getGroup('outsideGrid (all)')
# print information about the first few missing topologies and
# the elements contributing to the topology: 
for genEl in outsideGrid.generalElements[:5]:
    print ('\nmissing topology:',str(genEl._outputDescription))
    print ('Contributing elements:')
    for el in genEl._contributingElements:
        print('\t',el)
        print('\t element mass:',el.mass)


# In[ ]:




