#!/usr/bin/env python
# coding: utf-8

# ## Marginalize a combined result, instead of profiling it

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append( "." ); import smodels_paths


# In[2]:


from smodels.theory import decomposer
from smodels.installation import installDirectory
from smodels.theory.theoryPrediction import theoryPredictionsFor
from smodels.tools.physicsUnits import fb, GeV
from smodels.experiment.databaseObj import Database
from smodels.share.models.mssm import BSMList
from smodels.share.models.SMparticles import SMList
from smodels.theory.model import Model


# In[3]:


# load the official database
database = Database("unittest")


# In[4]:


# however filter out the aggregated CMS-SUS-16-050 result
expResult = database.getExpResults( analysisIDs=["CMS-SUS-16-050-agg"] )[0]


# In[5]:


# Check: print out the experimental result
print(expResult)


# In[6]:


# We look at a model that has gluinos -> t t LSP
filename="inputFiles/slha/gluinoToTops.slha"
model = Model(BSMList,SMList)
model.updateParticles(filename)


# In[7]:


# perform the decompoistion
topList = decomposer.decompose(model)
print ( topList )
for el in topList.getElements():
    print(el.toStr())
for tx in expResult.getTxNames():
    print(tx,tx.constraint)


# In[8]:


# obtain the theory predictions with marginalize=False
predProf = theoryPredictionsFor(expResult, topList, combinedResults=True, marginalize=False ) 


# In[9]:


# print the combined upper limit
print(predProf[1].getUpperLimit().asNumber(fb))


# In[10]:


# obtain the theory predictions with marginalize=True
predMarg = theoryPredictionsFor(expResult, topList, combinedResults=True, marginalize=True )


# In[11]:


# print the combined upper limit
print(predMarg[1].getUpperLimit().asNumber(fb))


# In[12]:


## for how to compute likelihoods and chi2 values, see the "compute_likelihood" how to.

