#!/usr/bin/env python
# coding: utf-8

# # How To: Compare theory predictions with experimental limits

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append("."); import smodels_paths


# In[2]:


# Import those parts of smodels that are needed for this exercise
# (We will assume the input is a SLHA file. For LHE files, use the lheDecomposer instead)
from smodels.share.models.mssm import BSMList
from smodels.share.models.SMparticles import SMList
from smodels.theory.model import Model
from smodels.theory import decomposer
from smodels.installation import installDirectory
from smodels.tools.physicsUnits import fb, GeV
from smodels.theory.theoryPrediction import theoryPredictionsFor
from smodels.experiment.databaseObj import Database


# In[3]:


# Define the SLHA input file name
filename="inputFiles/slha/gluino_squarks.slha" 
model = Model(BSMparticles = BSMList, SMparticles = SMList)
model.updateParticles(inputFile=filename)


# In[4]:


# Load the database, do the decomposition and compute theory predictions:
# (Look at the theory predictions HowTo to learn how to compute theory predictions)
database = Database("official")
expResults = database.getExpResults()
topList = decomposer.decompose(model, sigmacut = 0.03 * fb, doCompress=True, doInvisible=True,minmassgap = 5* GeV)
allThPredictions = [theoryPredictionsFor(exp, topList) for exp in expResults]


# In[5]:


# Print the value of each theory prediction for each experimental
# result and the corresponding upper limit (see the obtain experimental upper limits HowTo to learn how
# to compute the upper limits).
# lso print the expected upper limit, if available
for thPreds in allThPredictions:
    if not thPreds: continue #skip results with no predictions
    for theoryPred in thPreds:
        expID = theoryPred.expResult.globalInfo.id
        dataType = theoryPred.dataType()
        dataId = theoryPred.dataId()
        print ( "\nExperimental Result: %s (%s-type)" %(expID,dataType) ) #Result ID and type 
        print ( "Theory prediction xsec = ",theoryPred.xsection.value )#Signal xsection*efficiency*BR
        print ( "Upper limit = ",theoryPred.getUpperLimit() )
        print ( "Expected Upper limit = ",theoryPred.getUpperLimit(expected= True) )


# In[ ]:




