#!/usr/bin/env python
# coding: utf-8

# # How To: Print out the theoretical decomposition

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append("."); import smodels_paths


# In[2]:


# Import those parts of smodels that are needed for this exercise
# (We will assume the input is a SLHA file. For LHE files, use the lheDecomposer instead)
from smodels.share.models.mssm import BSMList
from smodels.share.models.SMparticles import SMList
from smodels.theory.model import Model
from smodels.theory import decomposer
from smodels.installation import installDirectory
from smodels.tools.physicsUnits import fb, GeV


# In[3]:


# Define the SLHA file name
filename="inputFiles/slha/gluino_squarks.slha"
model = Model(BSMparticles = BSMList, SMparticles = SMList)
model.updateParticles(inputFile=filename)


# In[4]:


# Perform the decomposition:
listOfTopologies = decomposer.decompose(model, sigmacut = 0.5 * fb, 
                                            doCompress=True, doInvisible=True,minmassgap = 5* GeV)


# In[5]:


# Print a summary of all the topologies generated:
for top in listOfTopologies:
    print (top.describe())


# In[6]:


# To print specific information about othe i-th topology:
i = 3
top = listOfTopologies[i]
print ("Number of vertices = ",top.vertnumb)
print ("Number of final states = ",top.vertparts)
print ("Number of elements = ",len(top.elementList))


# In[7]:


# We can also print information for each element in the topology:
for iel,element in enumerate(top.elementList):
    print ('Element',iel,':',element.evenParticles)
    print ('masses=',element.mass)
    print ('weight=',element.weight,'\n')


# In[ ]:




