#!/usr/bin/env python
# coding: utf-8

# # How To: Run SModelS using a parameter file

# In[1]:


# Set up the path to SModelS installation folder
import sys; sys.path.append("."); import smodels_paths


# In[2]:


# Import those parts of smodels that are needed for this exercise
from smodels.installation import installDirectory, version
from smodels.tools import modelTester
from smodels.tools import crashReport
from smodels.tools import smodelsLogging
from smodels.tools import runtime
from smodels import particlesLoader
from imp import reload


# In[3]:


#Define the SLHA file name
filename="inputFiles/slha/gluino_squarks.slha"
#Define the parameter file
parameterFile="./parameters.ini"


# In[4]:


#Read and check parameter file, exit parameterFile does not exist
parser = modelTester.getParameters(parameterFile)
#Display defined options:
for section in parser.sections():
    print(section)
    for option in parser.options(section):
        print('  ',option,'=',parser.get(section,option))


# In[5]:


#Change option:
parser.set('printer','outputtype','summary')


# In[6]:


#Determine particles module from ini file, if necessary """
if parser.has_option("particles","model"):
    runtime.modelFile = parser.get( "particles", "model" )
    reload(particlesLoader)

#Load the database defined in the parameters file, exit if not found """
database, databaseVersion = modelTester.loadDatabase(parser,db=None)
listOfExpRes = modelTester.loadDatabaseResults(parser, database)


# In[7]:


#Set local dir as output folder:
outputDir = './'
#run SModelS with input file:
output = modelTester.testPoint(filename, outputDir, parser, databaseVersion,listOfExpRes)


# [Download output](./gluino_squarks.slha.smodels)

# ### Display output:

# In[ ]:


# %load './gluino_squarks.slha.smodels'
Input status: 1
Decomposition output status: 1 #decomposition was successful
# Input File: inputFiles/slha/gluino_squarks.slha
# maxcond = 0.2
# minmassgap = 5.
# ncpus = 1
# sigmacut = 0.01
# Database version: 2.0.0-beta
================================================================================
#Analysis  Sqrts  Cond_Violation  Theory_Value(fb)  Exp_limit(fb)  r  r_expected

 ATLAS-SUSY-2016-07  1.30E+01    0.0  9.799E+00  1.270E+00  7.716E+00  9.158E+00
 Signal Region:  5j_Meff_1600
 Txnames:  T1, T2, T5GQ, T5WW, T5ZZ, T6WW, TGQ
 Chi2, Likelihood =  2.608E+02  2.279E-60
--------------------------------------------------------------------------------
     CMS-SUS-19-006  1.30E+01    0.0  1.169E+01  5.138E+00  2.274E+00  1.898E+00
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  6.356E+00  4.100E+00  1.550E+00  1.709E+00
 Signal Region:  SR3_Njet5_Nb0_HT500_MHT_500
 Txnames:  T1, T1bbbb, T1tttt, T2, T2tt, T5GQ, TGQ
 Chi2, Likelihood =  1.130E+01  3.432E-07
--------------------------------------------------------------------------------
     CMS-SUS-16-036  1.30E+01    0.0  1.169E+01  7.689E+00  1.520E+00  1.373E+00
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  1.169E+01  8.658E+00  1.350E+00  1.198E+00
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
     CMS-SUS-13-012  8.00E+00    0.0  3.447E-01  2.930E-01  1.177E+00  6.134E-01
 Signal Region:  6NJet8_1500HTinf_300MHTinf
 Txnames:  T1, T1bbbb, T1tttt, T2, T2tt, T5WW, T5ZZ, T6WW, T6bbWW, TChiWW, TChiZZ
 Chi2, Likelihood =  7.397E+00  6.147E-04
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  7.530E+00  6.785E+00  1.110E+00  5.420E-01
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-07  1.30E+01    0.0  4.911E+01  5.375E+01  9.138E-01  N/A
 Signal Region:  (UL)
 Txnames:  T6WW
--------------------------------------------------------------------------------
     CMS-SUS-16-036  1.30E+01    0.0  7.530E+00  9.298E+00  8.098E-01  4.447E-01
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-07  1.30E+01    0.0  1.169E+01  1.632E+01  7.161E-01  N/A
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
     CMS-SUS-19-006  1.30E+01    0.0  7.530E+00  1.273E+01  5.917E-01  6.798E-01
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
     CMS-SUS-13-019  8.00E+00    0.0  2.120E+00  3.762E+00  5.637E-01  N/A
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-02  8.00E+00    0.0  7.911E-01  1.818E+00  4.351E-01  5.231E-01
 Signal Region:  SR2jt
 Txnames:  T1, T2
 Chi2, Likelihood =  2.752E-01  1.202E-03
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-02  8.00E+00    0.0  6.736E+00  1.718E+01  3.920E-01  N/A
 Signal Region:  (UL)
 Txnames:  T6WW
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-02  8.00E+00    0.0  2.120E+00  6.096E+00  3.478E-01  N/A
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-04  8.00E+00    0.0  1.527E-01  5.060E-01  3.018E-01  3.291E-01
 Signal Region:  GtGrid_SR_7ej80_0bjet
 Txnames:  T1bbbb, T1tttt, T2tt, T5WW, T5ZZ, T6bbWW
 Chi2, Likelihood =  2.470E-01  1.833E-02
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-02  8.00E+00    0.0  9.069E+00  3.239E+01  2.800E-01  N/A
 Signal Region:  (UL)
 Txnames:  T5WW
--------------------------------------------------------------------------------
 ATLAS-SUSY-2015-06  1.30E+01    0.0  4.248E+00  1.570E+01  2.706E-01  2.706E-01
 Signal Region:  SR2jm
 Txnames:  T1, T2
 Chi2, Likelihood =  2.911E-01  4.739E-04
--------------------------------------------------------------------------------
 ATLAS-SUSY-2018-32  1.30E+01    0.0  1.446E+02  5.550E+02  2.605E-01  N/A
 Signal Region:  (UL)
 Txnames:  TChiWW
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-07  1.30E+01    0.0  7.530E+00  3.026E+01  2.489E-01  N/A
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
     CMS-SUS-13-012  8.00E+00    0.0  2.120E+00  1.077E+01  1.969E-01  3.478E-01
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
 ATLAS-SUSY-2019-08  1.30E+01    0.0  2.071E+02  1.148E+03  1.804E-01  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
 ATLAS-SUSY-2019-08  1.30E+01    0.0  9.065E-03  5.310E-02  1.707E-01  1.707E-01
 Signal Region:  SR_LM_High_MCT
 Txnames:  TChiWH
 Chi2, Likelihood =  2.421E-01  3.511E-02
--------------------------------------------------------------------------------
     CMS-SUS-17-004  1.30E+01    0.0  2.071E+02  1.572E+03  1.317E-01  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
     CMS-SUS-12-028  8.00E+00    0.0  2.120E+00  1.645E+01  1.289E-01  2.217E-01
 Signal Region:  (UL)
 Txnames:  T2
--------------------------------------------------------------------------------
     CMS-SUS-17-004  1.30E+01    0.0  3.990E+01  3.678E+02  1.085E-01  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-07  1.30E+01    0.0  1.032E+02  1.038E+03  9.939E-02  N/A
 Signal Region:  (UL)
 Txnames:  T5WW
--------------------------------------------------------------------------------
     CMS-SUS-16-039  1.30E+01    0.0  2.071E+02  2.115E+03  9.793E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
 ATLAS-SUSY-2018-31  1.30E+01    0.0  2.871E-01  3.185E+00  9.015E-02  N/A
 Signal Region:  (UL)
 Txnames:  T6bbHH
--------------------------------------------------------------------------------
     CMS-SUS-16-039  1.30E+01    0.0  3.990E+01  4.680E+02  8.526E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-16-045  1.30E+01    0.0  2.071E+02  2.437E+03  8.498E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
     CMS-SUS-13-006  8.00E+00    0.0  9.588E+01  1.136E+03  8.440E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-11  8.00E+00    0.0  4.477E-02  5.310E-01  8.431E-02  1.022E-01
 Signal Region:  WWc-DF
 Txnames:  TChiWW
 Chi2, Likelihood =  7.761E-02  2.082E-02
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-24  1.30E+01    0.0  7.639E-03  1.000E-01  7.639E-02  6.160E-02
 Signal Region:  WZ-0Jb
 Txnames:  TChiWZ
 Chi2, Likelihood =  1.663E+00  1.278E-01
--------------------------------------------------------------------------------
 ATLAS-SUSY-2018-31  1.30E+01    0.0  2.050E-03  2.990E-02  6.857E-02  4.012E-02
 Signal Region:  SRA_M
 Txnames:  T6bbHH
 Chi2, Likelihood =  1.675E+00  4.835E-02
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-24  1.30E+01    0.0  3.990E+01  5.848E+02  6.823E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-13-019  8.00E+00    0.0  6.619E-01  9.701E+00  6.823E-02  N/A
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-02  8.00E+00    0.0  6.619E-01  1.082E+01  6.118E-02  N/A
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
     CMS-SUS-13-012  8.00E+00    0.0  6.619E-01  1.114E+01  5.942E-02  8.244E-02
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
 ATLAS-SUSY-2018-06  1.30E+01    0.0  3.990E+01  8.254E+02  4.834E-02  7.675E-02
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-13-006  8.00E+00    0.0  1.847E+01  4.656E+02  3.967E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-12  8.00E+00    0.0  1.847E+01  4.844E+02  3.813E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-16-034  1.30E+01    0.0  3.990E+01  1.636E+03  2.439E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-12-028  8.00E+00    0.0  6.619E-01  3.144E+01  2.105E-02  3.453E-02
 Signal Region:  (UL)
 Txnames:  T1
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-11  8.00E+00    0.0  1.847E+01  9.250E+02  1.997E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-16-043  1.30E+01    0.0  2.071E+02  1.271E+04  1.629E-02  N/A
 Signal Region:  (UL)
 Txnames:  TChiWH
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-26  1.30E+01    0.0  2.488E-01  1.628E+01  1.528E-02  N/A
 Signal Region:  (UL)
 Txnames:  T2cc
--------------------------------------------------------------------------------
 ATLAS-SUSY-2017-03  1.30E+01    0.0  3.990E+01  4.178E+03  9.551E-03  N/A
 Signal Region:  (UL)
 Txnames:  TChiWZ
--------------------------------------------------------------------------------
     CMS-SUS-19-006  1.30E+01    0.0  1.536E-02  1.624E+00  9.459E-03  9.459E-03
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-19-006  1.30E+01    0.0  3.496E-02  4.203E+00  8.319E-03  8.932E-03
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-037  1.30E+01    0.0  3.496E-02  4.442E+00  7.870E-03  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-050  1.30E+01    0.0  3.496E-02  5.503E+00  6.354E-03  6.540E-03
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  3.496E-02  6.834E+00  5.116E-03  4.003E-03
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-036  1.30E+01    0.0  1.536E-02  3.360E+00  4.572E-03  3.087E-03
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-16-042  1.30E+01    0.0  3.496E-02  7.846E+00  4.456E-03  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-19-009  1.30E+01    0.0  1.004E-02  2.674E+00  3.755E-03  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  1.536E-02  4.921E+00  3.121E-03  3.169E-03
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-19-006  1.30E+01    0.0  1.004E-02  3.655E+00  2.747E-03  1.960E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-036  1.30E+01    0.0  3.496E-02  1.458E+01  2.398E-03  2.645E-03
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-009  1.30E+01    0.0  3.496E-02  1.703E+01  2.053E-03  1.480E-03
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-051  1.30E+01    0.0  1.004E-02  5.010E+00  2.004E-03  1.284E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-036  1.30E+01    0.0  1.004E-02  5.135E+00  1.955E-03  1.245E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-049  1.30E+01    0.0  1.004E-02  7.049E+00  1.424E-03  2.200E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-050  1.30E+01    0.0  1.004E-02  7.146E+00  1.405E-03  2.112E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-041  1.30E+01    0.0  3.496E-02  2.535E+01  1.379E-03  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-035  1.30E+01    0.0  3.496E-02  2.763E+01  1.265E-03  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-15  1.30E+01    0.0  1.004E-02  8.581E+00  1.170E-03  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-16  1.30E+01    0.0  1.004E-02  1.015E+01  9.896E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-16-033  1.30E+01    0.0  1.004E-02  1.071E+01  9.374E-04  1.160E-03
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-14  1.30E+01    0.0  3.496E-02  3.804E+01  9.190E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 CMS-PAS-SUS-13-023  8.00E+00    0.0  2.597E-03  3.014E+00  8.615E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-14-010  8.00E+00    0.0  3.074E-03  3.687E+00  8.337E-04  6.416E-04
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-18  8.00E+00    0.0  3.074E-03  3.780E+00  8.131E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-004  8.00E+00    0.0  2.597E-03  3.304E+00  7.861E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-13-007  8.00E+00    0.0  3.074E-03  4.128E+00  7.446E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-019  8.00E+00    0.0  1.350E-03  2.477E+00  5.453E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-16  1.30E+01    0.0  4.418E-04  8.610E-01  5.131E-04  8.367E-04
 Signal Region:  tN_med
 Txnames:  T2tt
 Chi2, Likelihood =  2.106E+00  1.188E-03
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-18  8.00E+00    0.0  1.191E-04  3.318E-01  3.589E-04  5.762E-04
 Signal Region:  SR-0l-4j-B
 Txnames:  T1bbbb
 Chi2, Likelihood =  9.694E-01  6.116E-02
--------------------------------------------------------------------------------
ATLAS-CONF-2013-061  8.00E+00    0.0  1.350E-03  3.774E+00  3.579E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-17-001  1.30E+01    0.0  1.004E-02  2.959E+01  3.394E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-13-019  8.00E+00    0.0  3.074E-03  9.129E+00  3.367E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-16-009  1.30E+01    0.0  1.004E-02  3.059E+01  3.282E-04  3.843E-04
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-18  8.00E+00    0.0  1.350E-03  4.117E+00  3.280E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-13-004  8.00E+00    0.0  1.350E-03  4.342E+00  3.110E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
     CMS-SUS-12-024  8.00E+00    0.0  1.186E-04  3.850E-01  3.082E-04  4.534E-04
 Signal Region:  MET4_HT4_nb3
 Txnames:  T1bbbb, T1tttt
 Chi2, Likelihood =  8.395E-01  4.657E-02
--------------------------------------------------------------------------------
ATLAS-CONF-2013-061  8.00E+00    0.0  3.074E-03  1.088E+01  2.825E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-04  8.00E+00    0.0  3.074E-03  1.091E+01  2.816E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-019  8.00E+00    0.0  2.597E-03  9.359E+00  2.775E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2015-02  1.30E+01    0.0  3.249E-04  1.260E+00  2.579E-04  2.579E-04
 Signal Region:  SR2
 Txnames:  T2tt
 Chi2, Likelihood =  5.152E-02  5.501E-01
--------------------------------------------------------------------------------
 ATLAS-SUSY-2013-09  8.00E+00    0.0  3.074E-03  1.356E+01  2.267E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-002  8.00E+00    0.0  3.074E-03  1.635E+01  1.879E-04  1.082E-07
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 ATLAS-SUSY-2016-17  1.30E+01    0.0  1.004E-02  5.358E+01  1.874E-04  N/A
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-13-012  8.00E+00    0.0  3.074E-03  1.661E+01  1.851E-04  2.741E-04
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-004  8.00E+00    0.0  3.074E-03  1.680E+01  1.829E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-13-013  8.00E+00    0.0  3.074E-03  1.765E+01  1.741E-04  1.624E-04
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
ATLAS-CONF-2013-089  8.00E+00    0.0  6.736E+00  4.051E+04  1.663E-04  N/A
 Signal Region:  (UL)
 Txnames:  T6WW
--------------------------------------------------------------------------------
     CMS-SUS-13-013  8.00E+00    0.0  4.164E-05  2.575E-01  1.617E-04  1.611E-04
 Signal Region:  SR28_HighPt
 Txnames:  T1tttt
 Chi2, Likelihood =  7.509E-03  1.098E-01
--------------------------------------------------------------------------------
     CMS-SUS-12-028  8.00E+00    0.0  1.350E-03  9.521E+00  1.418E-04  1.895E-04
 Signal Region:  (UL)
 Txnames:  T1bbbb
--------------------------------------------------------------------------------
ATLAS-CONF-2013-007  8.00E+00    0.0  3.074E-03  2.186E+01  1.406E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 CMS-PAS-SUS-13-016  8.00E+00    0.0  2.906E-05  2.110E-01  1.377E-04  1.371E-04
 Signal Region:  sr0
 Txnames:  T1tttt
 Chi2, Likelihood =  1.858E-02  1.387E-01
--------------------------------------------------------------------------------
     CMS-SUS-13-007  8.00E+00    0.0  2.066E-05  1.550E-01  1.333E-04  1.335E-04
 Signal Region:  mu350Nb3
 Txnames:  T1tttt
 Chi2, Likelihood =  1.201E+00  3.773E-01
--------------------------------------------------------------------------------
     CMS-SUS-17-010  1.30E+01    0.0  1.004E-02  8.087E+01  1.242E-04  1.273E-04
 Signal Region:  (UL)
 Txnames:  T2tt
--------------------------------------------------------------------------------
     CMS-SUS-12-024  8.00E+00    0.0  3.074E-03  2.617E+01  1.175E-04  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
 CMS-PAS-SUS-13-016  8.00E+00    0.0  3.074E-03  3.083E+01  9.971E-05  N/A
 Signal Region:  (UL)
 Txnames:  T1tttt
--------------------------------------------------------------------------------
     CMS-SUS-12-028  8.00E+00    0.0  3.074E-03  3.634E+01  8.458E-05  1.206E-04
 Signal Region:  (UL)
 Txnames:  T1tttt

 
================================================================================
The highest r value is = 7.7159013155030305

Total cross-section for missing topologies (fb):  2.838E+03
Total cross-section for missing topologies with displaced decays (fb):  0.000E+00
Total cross-section for missing topologies with prompt decays (fb):  2.838E+03
Total cross-section for topologies outside the grid (fb):  1.948E+02

Full information on unconstrained cross sections
================================================================================
missing topologies with the highest cross sections (up to 10):
Sqrts (TeV)   Weight (fb)                  Element description
 13.0          1.482E+02    #              [[[jet],[W]],[[jet,jet],[W]]]  (MET,MET)
 13.0          1.445E+02    #    [[[jet,jet],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          1.047E+02    #              [[[jet,jet],[W]],[[b,t],[W]]]  (MET,MET)
 13.0          8.754E+01    #                  [[[jet]],[[jet,jet],[W]]]  (MET,MET)
 13.0          7.520E+01    #                  [[[jet],[W]],[[b,t],[W]]]  (MET,MET)
 13.0          7.333E+01    #        [[[jet,jet],[W]],[[jet],[b,t],[W]]]  (MET,MET)
 13.0          7.333E+01    #        [[[b,t],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          6.576E+01    #        [[[jet],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          6.214E+01    #          [[[jet],[W]],[[jet,jet],[higgs]]]  (MET,MET)
 13.0          6.198E+01    #          [[[jet],[higgs]],[[jet,jet],[W]]]  (MET,MET)
================================================================================
No missing topologies with displaced decays found
================================================================================
missing topologies with prompt decays with the highest cross sections (up to 10):
Sqrts (TeV)   Weight (fb)                  Element description
 13.0          1.482E+02    #              [[[jet],[W]],[[jet,jet],[W]]]  (MET,MET)
 13.0          1.445E+02    #    [[[jet,jet],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          1.047E+02    #              [[[jet,jet],[W]],[[b,t],[W]]]  (MET,MET)
 13.0          8.754E+01    #                  [[[jet]],[[jet,jet],[W]]]  (MET,MET)
 13.0          7.520E+01    #                  [[[jet],[W]],[[b,t],[W]]]  (MET,MET)
 13.0          7.333E+01    #        [[[jet,jet],[W]],[[jet],[b,t],[W]]]  (MET,MET)
 13.0          7.333E+01    #        [[[b,t],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          6.576E+01    #        [[[jet],[W]],[[jet],[jet,jet],[W]]]  (MET,MET)
 13.0          6.214E+01    #          [[[jet],[W]],[[jet,jet],[higgs]]]  (MET,MET)
 13.0          6.198E+01    #          [[[jet],[higgs]],[[jet,jet],[W]]]  (MET,MET)
================================================================================
topologies outside the grid with the highest cross sections (up to 10):
Sqrts (TeV)   Weight (fb)                  Element description
 13.0          8.654E+01    #      [[[jet,jet],[higgs]],[[jet,jet],[W]]]  (MET,MET)
 13.0          4.111E+01    #              [[[jet],[higgs]],[[jet],[W]]]  (MET,MET)
 13.0          1.815E+01    #  [[[jet,jet],[higgs]],[[jet,jet],[higgs]]]  (MET,MET)
 13.0          1.667E+01    #          [[[jet,jet],[W]],[[jet,jet],[Z]]]  (MET,MET)
 13.0          8.603E+00    #          [[[jet],[higgs]],[[jet],[higgs]]]  (MET,MET)
 13.0          7.826E+00    #                  [[[jet],[W]],[[jet],[Z]]]  (MET,MET)
 13.0          6.992E+00    #      [[[jet,jet],[higgs]],[[jet,jet],[Z]]]  (MET,MET)
 13.0          3.245E+00    #              [[[jet],[higgs]],[[jet],[Z]]]  (MET,MET)
 13.0          1.852E+00    #                      [[[higgs]],[[higgs]]]  (MET,MET)
 13.0          1.438E+00    #                      [[[t],[W]],[[t],[W]]]  (MET,MET)
================================================================================


# In[ ]:




